@@ -9,7 +9,6 @@ write simpler bots.
 
 import sys
 import collections
-import warnings
 import abc
 import itertools
 import random
@@ -154,23 +153,16 @@ class SingleServerIRCBot(irc.client.SimpleIRCClient):
         server_list,
         nickname,
         realname,
-        reconnection_interval=missing,
+        _=None,
         recon=ExponentialBackoff(),
         **connect_params,
     ):
-        super(SingleServerIRCBot, self).__init__()
+        super().__init__()
         self.__connect_params = connect_params
         self.channels = IRCDict()
         specs = map(ServerSpec.ensure, server_list)
         self.servers = more_itertools.peekable(itertools.cycle(specs))
         self.recon = recon
-        # for compatibility
-        if reconnection_interval is not missing:
-            warnings.warn(
-                "reconnection_interval is deprecated; "
-                "pass a ReconnectStrategy object instead"
-            )
-            self.recon = ExponentialBackoff(min_interval=reconnection_interval)
 
         self._nickname = nickname
         self._realname = realname
@@ -351,7 +343,7 @@ class SingleServerIRCBot(irc.client.SimpleIRCClient):
     def start(self):
         """Start the bot."""
         self._connect()
-        super(SingleServerIRCBot, self).start()
+        super().start()
 
 
 class Channel:
