@@ -130,7 +130,7 @@ class ServerConnection(Connection):
     connected = False
 
     def __init__(self, reactor):
-        super(ServerConnection, self).__init__(reactor)
+        super().__init__(reactor)
         self.features = features.FeatureSet()
 
     # save the method args to allow for easier reconnection.
@@ -671,7 +671,9 @@ class ServerConnection(Connection):
 
     def set_keepalive(self, interval):
         """
-        Set a keepalive to occur every ``interval`` on this connection.
+        Set a keepalive to occur every `interval` on this `ServerConnection`.
+
+        :param interval: `int` in seconds, or `datetime.timedelta`
         """
         pinger = functools.partial(self.ping, 'keep-alive')
         self.reactor.scheduler.execute_every(period=interval, func=pinger)
@@ -954,7 +956,7 @@ class DCCConnection(Connection):
     peerport = None
 
     def __init__(self, reactor, dcctype):
-        super(DCCConnection, self).__init__(reactor)
+        super().__init__(reactor)
         self.dcctype = dcctype
 
     def connect(self, address, port):
